Documentation
¶
Overview ¶
Copyright © 2025 Benny Powers <web@bennypowers.com>
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
Index ¶
- func Validate(c *CemConfig) error
- type CSSTransformConfig
- type CemConfig
- type DemoDiscoveryConfig
- type DemosConfig
- type DesignTokensConfig
- type FrameworkExportConfig
- type GenerateConfig
- type HealthConfig
- type MCPConfig
- type ServeConfig
- type TransformsConfig
- type TypeScriptTransformConfig
- type URLRewrite
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CSSTransformConfig ¶ added in v0.7.0
type CSSTransformConfig = IC.CSSTransformConfig
type DemoDiscoveryConfig ¶
type DemoDiscoveryConfig = IC.DemoDiscoveryConfig
type DemosConfig ¶ added in v0.8.0
type DemosConfig = IC.DemosConfig
type DesignTokensConfig ¶
type DesignTokensConfig = IC.DesignTokensConfig
type FrameworkExportConfig ¶ added in v0.9.7
type FrameworkExportConfig = IC.FrameworkExportConfig
type GenerateConfig ¶
type GenerateConfig = IC.GenerateConfig
type HealthConfig ¶ added in v0.9.5
type HealthConfig = IC.HealthConfig
type ServeConfig ¶ added in v0.7.0
type ServeConfig = IC.ServeConfig
type TransformsConfig ¶ added in v0.7.0
type TransformsConfig = IC.TransformsConfig
type TypeScriptTransformConfig ¶ added in v0.7.0
type TypeScriptTransformConfig = IC.TypeScriptTransformConfig
type URLRewrite ¶ added in v0.8.0
type URLRewrite = IC.URLRewrite